<?php
if( ! function_exists( 'gs_get_woocommerce_version' ) ){
    /**
     * Public function to get WooCommerce version
     *
     * @return float|NULL
     */
    function gs_get_woocommerce_version() {
        if ( ! function_exists( 'get_plugins' ) )
            require_once( ABSPATH . 'wp-admin/includes/plugin.php' );

        $plugin_folder = get_plugins( '/' . 'woocommerce' );
        $plugin_file = 'woocommerce.php';

        if ( isset( $plugin_folder[$plugin_file]['Version'] ) ) {
            return $plugin_folder[$plugin_file]['Version'];
        } else {
            return NULL;
        }
    }
}
if( ! function_exists( 'gs_is_plugin_active' ) ) {
    function gs_is_plugin_active( $plugin_name, $version = '1.0.0.0', $version_end = '9.9.9.9' ) {
        switch ( $plugin_name ) {
            case 'filters':
                if ( defined ( "Gswcbr_AJAX_filters_version" ) &&
                Gswcbr_AJAX_filters_version >= $version &&
                Gswcbr_AJAX_filters_version <= $version_end ) {
                    return true;
                } else {
                    return false;
                }
            case 'list-grid':
                if ( defined ( "Gswcbr_List_Grid_version" ) &&
                Gswcbr_List_Grid_version >= $version &&
                Gswcbr_List_Grid_version <= $version_end ) {
                    return true;
                } else {
                    return false;
                }
            case 'more-products':
                if ( defined ( "Gswcbr_Load_More_Products_version" ) &&
                Gswcbr_Load_More_Products_version >= $version &&
                Gswcbr_Load_More_Products_version <= $version_end ) {
                    return true;
                } else {
                    return false;
                }
        }
    }
}

if ( ! function_exists( 'gswcbr_font_select_upload' ) ) {
    /**
     * Public function to add to plugin settings buttons to upload or select icons
     *
     * @param string $text - Text above buttons
     * @param string $id - input ID
     * @param string $name - input name
     * @param string $value - current value link or font awesome icon class
     * @param bolean $show_fa - show font awesome button and generate font awesome icon table
     * @param bolean $show_upload - show upload button that allow upload custom icons
     * @param bolean $show_remove - show remove button that allow clear input
     * @param string $data_sc - add data-sc options with this value into input 
     *
     * @return string html code with all needed blocks and buttons
     */
    function gswcbr_font_select_upload( $text, $id, $name, $value, $show_fa = true, $show_upload = true, $show_remove = true, $data_sc = '' ) {
        
        $result = '<div>';
        if ( $text && $text != '' ) {
            $result .= '<p>' . $text . '</p>';
        }
        $result .= '<input id="' . @ $id . '" type="text" name="' . @ $name . '" '.( ( $data_sc ) ? 'data-sc="'.$data_sc.'" ' : '' ).'value="' . @ $value . '"
            readonly style="display:none;" class="' . @ $name . ' '.( ( $data_sc ) ? 'gswcbr_aapf_widget_sc ' : '' ).'gswcbr_aapf_icon_text_value"/>
            <span class="gswcbr_aapf_selected_icon_show">
                ' . ( ( @ $value ) ? ( ( substr( $value, 0, 3 ) == 'fa-' ) ? '<i class="fa ' . $value . '"></i>' : '
            <image src="' . $value . '" alt="" style="height:250px;">' ) : '' ) . '</span>';
        
        if ( $show_upload ) {
            $result .= '<input type="button" class="gswcbr_aapf_upload_icon button" value="'.__('Upload', 'gswcbr_domain').'"/> ';
        }
        if ( $show_remove ) {
            $result .= '<input type="button" class="gswcbr_aapf_remove_icon button" value="'.__('Remove', 'gswcbr_domain').'"/>';
        }
        $result .= '</div>';

        return $result;
    }
}
?>