<?php
/**
 *
 * @package   GS_woocommerce_brands
 * @author    GS Plugins <samdani1997@gmail.com>
 * @license   GPL-1.0+
 * @link      https://gsplugins.com
 * @copyright 2018 GS Plugins
 *
 * @wordpress-plugin
 * Plugin Name:			GS Brands for WooCommerce Lite
 * Plugin URI:			https://gsplugins.com/wordpress-plugins
 * Description:       	GS WooCommerce Brands plugin add Brands taxonomy for WooCommerce Products. It's an extension of WooCommerce to create unlimited number of brands that can be assigned to the products for better cataloging. Use widgets to display brands list. Check documention here <a href=" http://woobrand.gsplugins.com/documentation"> WooCommerce Brands</a>
 * Version:           	1.2.2
 * Author:       		GS Plugins
 * Author URI:       	https://gsplugins.com
 * Text Domain:       	gswcbr
 * WC requires at least: 2.2
 * WC tested up to:     3.7.0
 * License:           	GPL-2.0+
 * License URI:       	http://www.gnu.org/licenses/gpl-2.0.txt
 */

define( "Gswcbr_product_brand_version", '1.2.2' );
define( "Gswcbr_product_brand_domain", 'Gswcbr_product_brand_domain');
define( "product_brand_TEMPLATE_PATH", plugin_dir_path( __FILE__ ) . "templates/" );
load_plugin_textdomain('Gswcbr_product_brand_domain', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/');
require_once(plugin_dir_path( __FILE__ ).'includes/functions.php');
require_once(plugin_dir_path( __FILE__ ).'gs-plugins/gs-plugins.php');
require_once(plugin_dir_path( __FILE__ ).'gs-plugins/gs-plugins-free.php');
require_once(plugin_dir_path( __FILE__ ).'gs-plugins/gs-woobrands-help.php');
include_once( ABSPATH . 'wp-admin/includes/plugin.php' );

if ( ! function_exists('gs_woobrands_pro_link') ) {
    function gs_woobrands_pro_link( $gsBrands_links ) {
        $gsBrands_links[] = '<a class="gs-pro-link" href="https://gsplugins.com/product/woocommerce-brands" target="_blank">Go Pro!</a>';
        $gsBrands_links[] = '<a href="https://gsplugins.com/wordpress-plugins" target="_blank">GS Plugins</a>';
        return $gsBrands_links;
    }
    add_filter( 'plugin_action_links_' .plugin_basename(__FILE__), 'gs_woobrands_pro_link' );
}

class gswcbr_product_brand {

    public static $info = array(
        'id'        => 19,
        'version'   => Gswcbr_product_brand_version,
        'plugin'    => '',
        'slug'      => '',
        'key'       => '',
        'name'      => ''
    );

    /**
     * Defaults values
     */
    public static $defaults = array(
        'display_thumbnail'                 => '',
        'brand_name_under_thumb'            => '',
        'brand_image_product_Page'          => '',
        'brand_image_product_Page_position' => '5',
        'thumbnail_width'                   => '50%',
        'display_description'               => '',
        'product_thumbnail'                 => 'e',
        'custom_css'                        => '',
        'custom_js'                         => '',
        'script'                            => array(
            'js_page_load'  => '',
        ),
        'plugin_key'                        => '',
    );
    public static $values = array(
        'settings_name' => 'gs-product_brand-options',
        'option_page'   => 'gs-product-brands',
        'premium_slug'  => 'woocommerce-brands',
    );

    function __construct () {
        register_activation_hook( __FILE__, array( __CLASS__, 'register_taxonomy' ), 10 );
        register_activation_hook( __FILE__, 'flush_rewrite_rules', 20 );
        register_uninstall_hook(__FILE__, array( __CLASS__, 'deactivation' ) );
        register_deactivation_hook(__FILE__,array( __CLASS__, 'gswcbr_deactivate'));
        add_action( 'admin_init', array( __CLASS__,'gswcbr_review_notice' ) );

        add_action ( 'init', array( __CLASS__, 'register_taxonomy' ) );
        if ( ( is_plugin_active( 'woocommerce/woocommerce.php' ) || is_plugin_active_for_network( 'woocommerce/woocommerce.php' ) ) &&
            gs_get_woocommerce_version() >= 2.1 ) {
            $options = self::get_option();

            add_action( 'init', array( __CLASS__, 'init' ) );
            add_action( 'wp_head', array( __CLASS__, 'set_styles' ) );
            add_action( 'wp_footer', array( __CLASS__, 'set_js' ) );
            add_action( 'admin_init', array( __CLASS__, 'admin_init' ) );
            add_action( 'admin_enqueue_scripts', array( __CLASS__, 'admin_enqueue_scripts' ) );
            add_action( 'wp_enqueue_scripts', array( __CLASS__, 'front_enqueue_scripts' ) );
            add_action( 'admin_menu', array( __CLASS__, 'options' ) );
            add_action( "wp_ajax_gs_product_brand_settings_save", array ( __CLASS__, 'save_settings' ) );
            add_action( "woocommerce_archive_description", array ( __CLASS__, 'description' ) );
            add_shortcode( 'brands_products', array( __CLASS__, 'products_shortcode' ) );
            add_shortcode( 'brands_carousal', array( __CLASS__, 'brands_carosal_shortcode' ) );
            add_shortcode( 'product_brand', array( __CLASS__, 'products_brands_shortcode' ) );
            add_filter( 'template_include', array( __CLASS__, 'template_loader' ) );
            
            if( isset($options['brand_select_position']) && $options['brand_select_position']=='belowtitle' ){
                add_action( 'woocommerce_after_shop_loop_item_title', array( __CLASS__, 'add_brand_shop_page' ) );
            } elseif( isset($options['brand_select_position']) && $options['brand_select_position']=='abovetitle' ){
                add_action( 'woocommerce_shop_loop_item_title', array( __CLASS__, 'add_brand_shop_page' ) );
            }else{
                add_action( 'woocommerce_after_shop_loop_item', array( __CLASS__, 'add_brand_shop_page' ) );
            }
            
            $plugin_base_slug = plugin_basename( __FILE__ );
            add_filter( 'plugin_action_links_' . $plugin_base_slug, array( __CLASS__, 'plugin_action_links' ) );

            //extra features
            if(isset($options['brand_name_product_page'])){
                add_action( 'woocommerce_before_single_product', array ( __CLASS__, 'show_brands_name_on_product_thumb' ) );
            }
         
            add_action( 'woocommerce_single_product_summary', array ( __CLASS__, 'add_brand_thumb_to_product_page' ), $options['brand_image_product_Page_position'] );
        }
    }

    public static function show_brands_name_on_product_thumb() {
        global $post;
        $args = array( 'taxonomy' => 'gswcbr_brand',);
        $terms = wp_get_post_terms($post->ID,'gswcbr_brand', $args);
        $options = self::get_option();
        $brand_position=$options['select__product_position'];

        $show = "<span>";
        if (isset ($brand_position) ) {
            foreach ($terms as $term) {
                $show .=  '<a href="'. get_term_link( $term->term_id, 'gswcbr_brand' ). '"> ' . $term->name. '  </a> '; 
            }
        }
        $show .="</span>";

        switch ( $brand_position ) {
                
            case 'below-tab':
                echo "<script type='text/javascript'>
                    jQuery(document).ready(function(){
                        jQuery('" . $show . "').insertAfter('.woocommerce-tabs');
                    });
                </script>
                ";
                break;
            case 'above-des':
                echo "<script type='text/javascript'>
                    jQuery(document).ready(function(){
                        jQuery('" . $show . "').insertBefore('div.woocommerce-product-details__short-description');
                    });
                </script>
                ";
                break;
            case 'below-des':
                echo "<script type='text/javascript'>
                    jQuery(document).ready(function(){
                        jQuery('" . $show . "').insertAfter('div.woocommerce-product-details__short-description');
                    });
                </script>
                ";
                break;
            case 'above-cart':
                echo "<script type='text/javascript'>
                    jQuery(document).ready(function(){
                        jQuery('" . $show . "').insertBefore('form.cart');
                    });
                </script>
                ";
                break;
            case 'below-cart':
                echo "<script type='text/javascript'>
                    jQuery(document).ready(function(){
                        jQuery('" . $show . "').insertAfter('form.cart');
                    });
                </script>
                ";
                break;
            
            case 'below-category':
                echo "<script type='text/javascript'>
                    jQuery(document).ready(function(){
                        jQuery('" . $show . "').insertAfter('.product_meta');
                    });
                </script>
                ";
                break;

            default:
                echo "<script type='text/javascript'>
                    jQuery(document).ready(function(){
                        jQuery('" . $show . "').insertBefore('.woocommerce-tabs');
                    });
                </script>
        ";
        }   
    }

    public static  function add_brand_shop_page() {
        global $post;
        $args = array( 'taxonomy' => 'gswcbr_brand',);
        $terms = wp_get_post_terms($post->ID,'gswcbr_brand', $args);
        $options = self::get_option();
        
        if (! empty($terms) &&  isset( $options['display_Brandname'] ) ) {

        echo '<div class="gs-brand-on-shop">';
            if( isset($options['brand_level_shop_page']) && $options['brand_level_shop_page']=='1' ) {
                echo '<span>'.$options['brand_level_text']." : ".'</span>';
            }
        
            foreach ($terms as $term) {
                echo '<a href="', get_term_link( $term->term_id, 'gswcbr_brand' ), '">', $term->name, '  </a>  ';
            }
        echo '</div>';
        }
    }

    public static function add_brand_thumb_to_product_page() {
        global $post;
        $options = self::get_option();
        if ($options['brand_image_product_Page'] == 1 ) {
            echo do_shortcode('[product_brand id="'.$post->ID.'" width="'.$options['brand_imaze_size'].'" height="64px"]');
        }
    }

    public static function products_brands_shortcode($atts = array()) {
        global $post;
        $atts = shortcode_atts( array(
            'id'        => '',
            'width'     => '64px',
            'height'    => '64px',
            'class'     => 'gswcbr',
        ), $atts );

        $args = array( 'taxonomy' => 'gswcbr_brand',);
        $terms = wp_get_post_terms($atts['id'],'gswcbr_brand', $args);
        $single_product_brands=' ';
        foreach ($terms as $term) {
            $image  = get_term_meta( $term->term_id, 'brand_image_url', true );
            if( ! empty($image) ) {
               $single_product_brands .='<div class="product-brand">';
                // $single_product_brands .= '<a class="'.$atts['class'].'" href="'.get_term_link( $term->term_id, 'gswcbr_brand' ). '"><img style="max-height:'. $atts['height']. '; width:'. $atts['width'].';" src="'. $image. '" alt="'. $term->name.'"></a>';
                $single_product_brands .= '<a class="'.$atts['class'].'" href="'.get_term_link( $term->term_id, 'gswcbr_brand' ). '"><img style="width:'. $atts['width'].';" src="'. $image. '" alt="'. $term->name.'"></a>';
              $single_product_brands .='</div>';
            }
        }
        return $single_product_brands;
    }
        
    public static function plugin_action_links($links) {
		$action_links = array(
			'settings' => '<a href="' . admin_url( 'admin.php?page='.self::$values['option_page'] ) . '" title="' . __( 'View Plugin Settings', 'Gswcbr_products_label_domain' ) . '">' . __( 'Settings', 'Gswcbr_products_label_domain' ) . '</a>',
		);
		return array_merge( $action_links, $links );
    }
    
    public static function template_loader( $template ) {

		$find = array( 'woocommerce.php' );
		$file = '';

		if ( is_tax( 'gswcbr_brand' ) ) {

			$term = get_queried_object();

			$woocommerce_url = apply_filters( 'woocommerce_template_url', 'woocommerce/' );
            $file   = 'taxonomy-' . $term->taxonomy . '.php';
			$find[] = 'taxonomy-' . $term->taxonomy . '-' . $term->slug . '.php';
			$find[] = $woocommerce_url . 'taxonomy-' . $term->taxonomy . '-' . $term->slug . '.php';
			$find[] = $file;
			$find[] = $woocommerce_url . $file;
		}

		if ( $file ) {
			$template = locate_template( $find );
			if ( ! $template ) $template = product_brand_TEMPLATE_PATH . $file;
		}

		return $template;
	}
    public static function brands_carosal_shortcode($atts = array()) {

        $options = Gswcbr_product_brand::get_option(); 
        if( isset( $options['brand_select_theme'] ) ){
        $theme = $options['brand_select_theme'];
        } else{
        	$theme='slider1';
        }
        $theme =$theme ;

        extract( shortcode_atts( array(
            'theme'         => $theme,
            'name'          => 'on',
            'image'         => 'on',
            'description'   => 'off',
          	'col'           => 3,  
            ), $atts));

        if($col==3) {
        	$col=4;
        } elseif($col==4) {
        	$col=3;
        } elseif($col==6) {
        	$col=2;
        } else {
        	$col=3;
        }

        $terms = get_terms( 'gswcbr_brand', array(
            'hide_empty'    => true,
            'fields'        => 'all',
        ) );
        $output ='';
        ob_start();

        if($theme=='slider1'){
            $output = include product_brand_TEMPLATE_PATH . '/gs_brand_carousal.php';
        }
        if($theme=='slider2'){
            $output = include product_brand_TEMPLATE_PATH . '/gs_brand_carousal2.php';
        }
                
        $output .=ob_get_contents();
  
        return $output;
    }

    public static function products_shortcode($atts = array()) {
        $atts = shortcode_atts( array(
			'columns'   => '4',
			'orderby'   => 'title',
			'order'     => 'DESC',
			'brand_id'  => '',
			'brand_slug'=> '',
			'operator'  => 'IN'
		), $atts );

		if ( ! @ $atts['brand_id'] && ! @ $atts['brand_slug'] ) {
			return '';
		}

		// Default ordering args
		$ordering_args = WC()->query->get_catalog_ordering_args( $atts['orderby'], $atts['order'] );
		$meta_query    = WC()->query->get_meta_query();
        if( @ $atts['brand_id'] ) {
            $brand          = $atts['brand_id'];
            $brand_field    = 'id';
        } elseif( @ $atts['brand_slug'] ) {
            $brand          = $atts['brand_slug'];
            $brand_field    = 'slug';
        }
		$query_args    = array(
			'post_type'            => 'product',
			'post_status'          => 'publish',
			'orderby'              => $ordering_args['orderby'],
			'order'                => $ordering_args['order'],
			'posts_per_page'       => (empty($atts['per_page']) ? '12' : $atts['per_page']),
			'meta_query'           => $meta_query,
			'tax_query'            => array(
				array(
					'taxonomy'     => 'gswcbr_brand',
					'terms'        => explode( ',', $brand ),
					'field'        => $brand_field,
					'operator'     => $atts['operator']
				)
			)
		);
        if( empty($atts['per_page']) ) {
            unset($atts['per_page']);
        }

		if ( isset( $ordering_args['meta_key'] ) ) {
			$query_args['meta_key'] = $ordering_args['meta_key'];
		}

		$return = self::product_loop( $query_args, $atts, 'product_cat' );

		// Remove ordering query arguments
		WC()->query->remove_ordering_args();

		return $return;
    }
	private static function product_loop( $query_args, $atts, $loop_name ) {
		global $woocommerce_loop;

		$products                    = new WP_Query( apply_filters( 'woocommerce_shortcode_products_query', $query_args, $atts, $loop_name ) );
		$columns                     = absint( $atts['columns'] );
		$woocommerce_loop['columns'] = $columns;
		$woocommerce_loop['name']    = $loop_name;

		ob_start();
		if ( $products->have_posts() ) {
			?>

			<?php do_action( "woocommerce_shortcode_before_{$loop_name}_loop" ); ?>

			<?php woocommerce_product_loop_start(); ?>

				<?php while ( $products->have_posts() ) : $products->the_post(); ?>
					<?php wc_get_template_part( 'content', 'product' ); ?>
				<?php endwhile; // end of the loop. ?>

			<?php woocommerce_product_loop_end(); ?>

			<?php do_action( "woocommerce_shortcode_after_{$loop_name}_loop" ); ?>

			<?php
		} else {
			do_action( "woocommerce_shortcode_{$loop_name}_loop_no_results" );
		}

		woocommerce_reset_loop();
		wp_reset_postdata();

		return '<div class="woocommerce columns-' . $columns . ' gs-brand">' . ob_get_clean() . '</div>';
	}

    public static function register_taxonomy () {
        $shop_page_id = wc_get_page_id( 'shop' );
	    $base_slug = $shop_page_id > 0 && get_page( $shop_page_id ) ? get_page_uri( $shop_page_id ) : 'shop';
	    $category_base = get_option('woocommerce_prepend_shop_page_to_urls') == "yes" ? trailingslashit( $base_slug ) : '';

		register_taxonomy( 'gswcbr_brand',
			array('product'),
			array(
				'hierarchical'          => true,
				'update_count_callback' => '_update_post_term_count',
				'label'                 => __( 'Brands', 'Gswcbr_product_brand_domain'),
				'labels'                => array(
                    'name'                  => __( 'Brands', 'Gswcbr_product_brand_domain' ),
                    'singular_name'         => __( 'Brand', 'Gswcbr_product_brand_domain' ),
                    'search_items'          => __( 'Search Brands', 'Gswcbr_product_brand_domain' ),
                    'all_items'             => __( 'All Brands', 'Gswcbr_product_brand_domain' ),
                    'parent_item'           => __( 'Parent Brand', 'Gswcbr_product_brand_domain' ),
                    'parent_item_colon'     => __( 'Parent Brand:', 'Gswcbr_product_brand_domain' ),
                    'edit_item'             => __( 'Edit Brand', 'Gswcbr_product_brand_domain' ),
                    'update_item'           => __( 'Update Brand', 'Gswcbr_product_brand_domain' ),
                    'add_new_item'          => __( 'Add New Brand', 'Gswcbr_product_brand_domain' ),
                    'new_item_name'         => __( 'New Brand Name', 'Gswcbr_product_brand_domain' )
				),
				'show_ui'               => true,
				'show_in_menu'          => true,
				'show_admin_column'     => true,
				'show_in_nav_menus'     => true,
				'show_in_quick_edit'    => false,
				'meta_box_cb'           => 'post_categories_meta_box',
				'capabilities'          => array(
					'manage_terms' => 'manage_product_terms',
					'edit_terms'   => 'edit_product_terms',
					'delete_terms' => 'delete_product_terms',
					'assign_terms' => 'assign_product_terms'
				),

				'rewrite' => array( 'slug' => $category_base . 'brands', 'with_front' => true, 'hierarchical' => true )
			)
		);
    }

    public static function init () {
		global $woocommerce;

        $options = self::get_option();
        wp_enqueue_script("jquery");
        wp_register_style( 'gswcbr_product_brand_style',
            plugins_url( 'css/frontend.css', __FILE__ ),
            "",
            Gswcbr_product_brand_version );
        wp_enqueue_style( 'gswcbr_product_brand_style' );
    }
    
    /**
     * Function set styles in wp_head WordPress action
     *
     * @return void
     */
    public static function set_styles () {
        $options = self::get_option();
        if($options['display_description']==1){
            $display='block';
        }
        else{
            $display='none';
        }
        
        echo '<style>'
        .$options['custom_css'].
         '.gsbrand-vertical-carousal .text-center, .horizontal-filter,.normal-grid,.gsbrand-class .text-center,.gsbrand-slider2 .text-center {
            width:'. $options['container_width'].'px;
            margin: 0 auto;
        }
        .term-description {
            display: '.$display.';
        }'.
        '</style>';
    }
    
    /**
     * Function set styles in wp_head WordPress action
     *
     * @return void
     */
    public static function set_js () {
        $options = self::get_option();
        echo '<scripts>'.$options['custom_js'].'</scripts>';
    }
    /**
     * Load template
     *
     * @access public
     *
     * @param string $name template name
     *
     * @return void
     */
    public static function gs_get_template_part( $name = '' ) {
        $template = '';

        // Look in your_child_theme/woocommerce-product_brand/name.php
        if ( $name ) {
            $template = locate_template( "woocommerce-product_brand/{$name}.php" );
        }

        // Get default slug-name.php
        if ( ! $template && $name && file_exists( product_brand_TEMPLATE_PATH . "{$name}.php" ) ) {
            $template = product_brand_TEMPLATE_PATH . "{$name}.php";
        }

        // Allow 3rd party plugin filter template file from their plugin
        $template = apply_filters( 'product_brand_get_template_part', $template, $name );

        if ( $template ) {
            load_template( $template, false );
        }
    }

    public static function admin_enqueue_scripts() {
        if ( function_exists( 'wp_enqueue_media' ) ) {
            wp_enqueue_media();
        } else {
            wp_enqueue_style( 'thickbox' );
            wp_enqueue_script( 'media-upload' );
            wp_enqueue_script( 'thickbox' );
        }

        wp_enqueue_style( 'mailchip-style', '//cdn-images.mailchimp.com/embedcode/slim-081711.css','','' );

    }

    public static function front_enqueue_scripts() {
        $options = self::get_option();
        //wp_enqueue_style( 'bootstrap', plugins_url( 'css/gs-brand-bootstrap.css', __FILE__ ) );
        wp_enqueue_style( 'slick', plugins_url( 'css/slick.css', __FILE__ ) );
        wp_enqueue_style( 'slick-theme', plugins_url( 'css/slick-theme.css', __FILE__ ) );
        wp_enqueue_script( 'slick-js', plugins_url( 'js/slick.min.js', __FILE__ ), array( 'jquery' ), Gswcbr_product_brand_version,true );
        wp_enqueue_script( 'popper-js', plugins_url( 'js/popper.min.js', __FILE__ ), array( 'jquery' ), Gswcbr_product_brand_version,true );
        wp_enqueue_script( 'boot-js', plugins_url( 'js/bootstrap.min.js', __FILE__ ), array( 'jquery' ), Gswcbr_product_brand_version,true );
        wp_enqueue_script( 'breand-c-js', plugins_url( 'js/gs_brand_custom.js', __FILE__ ), array( 'jquery' ), Gswcbr_product_brand_version,true );
        wp_localize_script( 'breand-c-js', 'object_name',  array( 
            'tooltip_switch' => isset( $options['display_tooltip'] ),
        ) );
    }

    /**
     * Function adding styles/scripts and settings to admin_init WordPress action
     *
     * @access public
     *
     * @return void
     */
    public static function admin_init () {
        wp_register_style( 'font-awesome', plugins_url( 'css/font-awesome.min.css', __FILE__ ) );
        wp_enqueue_style( 'font-awesome' );
        wp_enqueue_script( 'gswcbr_product_brand_admin', plugins_url( 'js/admin.js', __FILE__ ), array( 'jquery' ), Gswcbr_product_brand_version );
        wp_register_style( 'gswcbr_product_brand_admin_style', plugins_url( 'css/admin.css', __FILE__ ), "", Gswcbr_product_brand_version );
        wp_enqueue_style( 'gswcbr_product_brand_admin_style' );
        wp_register_style( 'gswcbr_gs_free_plugins_style', plugins_url( 'css/gs_free_plugins.css', __FILE__ ), "", Gswcbr_product_brand_version );
        wp_enqueue_style( 'gswcbr_gs_free_plugins_style' );
		add_action( 'gswcbr_brand_add_form_fields', array( __CLASS__, 'add_field' ) );
		add_action( 'gswcbr_brand_edit_form_fields', array( __CLASS__, 'edit_field' ), 10, 2 );
		add_action( 'created_term', array( __CLASS__, 'field_save' ), 10, 3 );
		add_action( 'edit_term', array( __CLASS__, 'field_save' ), 10, 3 );
    }
    public static function add_field () {
        echo '<table class="form-table">
    		<tbody>
                <tr class="form-field term-name-wrap">
        			<th scope="row"><label for="name">', __( 'Thumbnail', 'Gswcbr_product_brand_domain' ), '</label></th>
        			<td><div class="gs_brands_image">', gswcbr_font_select_upload('', 'gs_brand_options_ajax_load_icon', 'gs_brand_image', '', true), '</div></td>
        		</tr>
			</tbody>
        </table>';
    }
    public static function edit_field ( $term, $taxonomy ) {
        $image 	= get_term_meta( $term->term_id, 'brand_image_url', true );
        echo '<table class="form-table">
            <tbody>
                <tr class="form-field term-name-wrap">
                    <th scope="row"><label for="name">', __( 'Thumbnail', 'Gswcbr_product_brand_domain' ), '</label></th>
                    <td><div class="gs_brands_image">', gswcbr_font_select_upload('', 'gs_brand_options_ajax_load_icon', 'gs_brand_image', @ $image, false), '</div></td>
                </tr>
            </tbody>
        </table>';
    }

    public static  function gsbrand_sanitize_image( $input ){

            /* default output */
            $output = '';
        
            /* check file type */
            $filetype = wp_check_filetype( $input );
            $mime_type = $filetype['type'];
        
            /* only mime type "image" allowed */
            if ( strpos( $mime_type, 'image' ) !== false ){
                $output = $input;
            }
        
            return $output;
        }

    public static function field_save ( $term_id, $tt_id, $taxonomy ) {
        if ( isset( $_POST['gs_brand_image'] ) ) {
  			update_woocommerce_term_meta( $term_id, 'brand_image_url', esc_url_raw( self::gsbrand_sanitize_image($_POST['gs_brand_image'] ) ));
  		}
    }

    public static function description() {
        if( ! is_tax('gswcbr_brand') ) {
            return;
        }
		if ( ! get_query_var( 'gswcbr_brand' ) && ! get_query_var( 'term' ) ) {
			return;
        }
        $term_find = get_query_var( 'gswcbr_brand' );
        $term_find = ( empty($term_find) ? get_query_var( 'term' ) : $term_find );
        $term = get_term_by( 'slug', $term_find, 'gswcbr_brand' );
        if( empty($term) ) {
            return;
        }
        $image 	= get_term_meta( $term->term_id, 'brand_image_url', true );
        $options = self::get_option();
        set_query_var( 'display_thumbnail', @ $options['display_thumbnail'] );
        set_query_var( 'width', @ $options['thumbnail_width'] );
        set_query_var( 'display_description', @ $options['display_description'] );
        set_query_var( 'brand_term', @ $term );
        set_query_var( 'brand_image', @ $image );
        self::gs_get_template_part( 'description' ); 
    }

    public static function description_post($atts = array()) { 
        $atts = shortcode_atts( array(
			'post_id'   => '',
			'width'     => '35%',
			'height'    => '',
		), $atts );
        if( empty($atts['post_id']) ) {
            $atts['post_id'] = get_the_ID();
            if( empty($atts['post_id']) ) {
                return;
            }
        }
        $terms = get_the_terms($atts['post_id'], 'gswcbr_brand');
        if( empty($terms) ) {
            return;
        }
        if( ! empty($terms) && is_array($terms) ) {
            foreach($terms as $term) {
                $image 	= get_term_meta( $term->term_id, 'brand_image_url', true );
                if( ! empty($image) ) {
                    echo '<img class="gswcbr_brand_post_image" src="', $image, '" alt="', $term->name, '" style="',
                    (empty($atts['width']) ? '' : 'width:'.$atts['width'].';'),
                    (empty($atts['height']) ? '' : 'height:'.$atts['height'].';'), '">';
                }
            }
        }
    }
    /**
     * Function add options button to admin panel
     *
     * @access public
     *
     * @return void
     */
    public static function options() {
        // add_submenu_page( 'woocommerce', __('Gs Product Brands settings', 'Gswcbr_product_brand_domain'), __('Gs Product Brands', 'Gswcbr_product_brand_domain'), 'manage_options', 'gs-product_brand', array(
        //     __CLASS__,
        //     'option_form'
        // ) );

        add_submenu_page( 'gsp-main', __('GS Product Brands Settings', 'Gswcbr_product_brand_domain'), __('GS Product Brands', 'Gswcbr_product_brand_domain'), 'manage_options', 'gs-product-brands', array(
            __CLASS__,
            'option_form'
        )); 
    }
    /**
     * Function add options form to settings page
     *
     * @access public
     *
     * @return void
     */
    public static function option_form() {
        $plugin_info = get_plugin_data(__FILE__, false, true);
        include product_brand_TEMPLATE_PATH . "settings.php";
    }

    /**
     * Function remove settings from database
     *
     * @return void
     */
    public static function deactivation () {
        delete_option( self::$values['settings_name'] );
    }

    /**
     * @gswcbr_review_dismiss()
     * @gswcbr_review_pending()
     * @gswcbr_review_notice_message()
     * Make all the above functions working.
     */
    public static function  gswcbr_review_notice(){

        self::gswcbr_review_dismiss();
        self::gswcbr_review_pending();

        $activation_time    = get_site_option( 'gswcbr_active_time' );
        $review_dismissal   = get_site_option( 'gswcbr_review_dismiss' );
        $maybe_later        = get_site_option( 'gswcbr_maybe_later' );

        if ( 'yes' == $review_dismissal ) {
            return;
        }

        if ( ! $activation_time ) {
            add_site_option( 'gswcbr_active_time', time() );
        }
        
        $daysinseconds = 259200; // 3 Days in seconds.
    
        if( 'yes' == $maybe_later ) {
            $daysinseconds = 604800 ; // 7 Days in seconds.
        }

        if ( time() - $activation_time > $daysinseconds ) {
            add_action( 'admin_notices' , array( __CLASS__,'gswcbr_review_notice_message') );
        }
    }

    /**
     * For the notice preview.
    */
    public static function gswcbr_review_notice_message(){
        $scheme      = (parse_url( $_SERVER['REQUEST_URI'], PHP_URL_QUERY )) ? '&' : '?';
        $url         = $_SERVER['REQUEST_URI'] . $scheme . 'gswcbr_review_dismiss=yes';
        $dismiss_url = wp_nonce_url( $url, 'gswcbr-review-nonce' );

        $_later_link = $_SERVER['REQUEST_URI'] . $scheme . 'gswcbr_review_later=yes';
        $later_url   = wp_nonce_url( $_later_link, 'gswcbr-review-nonce' );
        ?>
        
        <div class="gslogo-review-notice">
            <div class="gslogo-review-thumbnail">
                <img src="<?php echo plugins_url( 'css/icon-128x128.png', __FILE__ );?>" alt="">
            </div>
            <div class="gslogo-review-text">
                <h3><?php _e( 'Leave A Review?', 'gswcbr' ) ?></h3>
                <p><?php _e( 'We hope you\'ve enjoyed using <b>GS Brands for WooCommerce</b>! Would you consider leaving us a review on WordPress.org?', 'gswcbr' ) ?></p>
                <ul class="gslogo-review-ul">
                    <li>
                        <a href="https://wordpress.org/support/plugin/gs-woo-brands/reviews/" target="_blank">
                            <span class="dashicons dashicons-external"></span>
                            <?php _e( 'Sure! I\'d love to!', 'gswcbr' ) ?>
                        </a>
                    </li>
                    <li>
                        <a href="<?php echo $dismiss_url ?>">
                            <span class="dashicons dashicons-smiley"></span>
                            <?php _e( 'I\'ve already left a review', 'gswcbr' ) ?>
                        </a>
                    </li>
                    <li>
                        <a href="<?php echo $later_url ?>">
                            <span class="dashicons dashicons-calendar-alt"></span>
                            <?php _e( 'Maybe Later', 'gswcbr' ) ?>
                        </a>
                    </li>
                    <li>
                        <a href="https://gsplugins.com/support/" target="_blank">
                            <span class="dashicons dashicons-sos"></span>
                            <?php _e( 'I need help!', 'gswcbr' ) ?>
                        </a>
                    </li>
                    <li>
                        <a href="<?php echo $dismiss_url ?>">
                            <span class="dashicons dashicons-dismiss"></span>
                            <?php _e( 'Never show again', 'gswcbr' ) ?>
                        </a>
                    </li>
                </ul>
            </div>
        </div>
        
        <?php
    }
    /**
     * For Dismiss! 
    */
    public static function gswcbr_review_dismiss(){

        if ( ! is_admin() ||
            ! current_user_can( 'manage_options' ) ||
            ! isset( $_GET['_wpnonce'] ) ||
            ! wp_verify_nonce( sanitize_key( wp_unslash( $_GET['_wpnonce'] ) ), 'gswcbr-review-nonce' ) ||
            ! isset( $_GET['gswcbr_review_dismiss'] ) ) {

            return;
        }

        add_site_option( 'gswcbr_review_dismiss', 'yes' );   
    }

    /**
     * For Maybe Later Update.
    */
    public static function gswcbr_review_pending() {

        if ( ! is_admin() ||
            ! current_user_can( 'manage_options' ) ||
            ! isset( $_GET['_wpnonce'] ) ||
            ! wp_verify_nonce( sanitize_key( wp_unslash( $_GET['_wpnonce'] ) ), 'gswcbr-review-nonce' ) ||
            ! isset( $_GET['gswcbr_review_later'] ) ) {

            return;
        }
        // Reset Time to current time.
        update_site_option( 'gswcbr_active_time', time() );
        update_site_option( 'gswcbr_maybe_later', 'yes' );

    }

    public static function gswcbr_deactivate () {
        delete_option('gswcbr_active_time');
        delete_option('gswcbr_maybe_later');
    }
    public static function save_settings () {

        
        if( current_user_can( 'manage_options' ) ) {
            if( isset($_POST[self::$values['settings_name']]) ) {
                update_option( self::$values['settings_name'], self::sanitize_option($_POST[self::$values['settings_name']]) );

                
                echo json_encode(  wp_unslash( $_POST[self::$values['settings_name']] ) );
            }
        }
        wp_die();
    }

    public static function sanitize_option( $input ) {
        $default = self::$defaults;
        $result = self::recursive_array_set( $default, $input );
        return $result;
    }
    public static function recursive_array_set( $default, $options ) {
        $result = array();
        foreach( $default as $key => $value ) {
            if( array_key_exists( $key, $options ) ) {
                if( is_array( $value ) ) {
                    if( is_array( $options[$key] ) ) {
                        $result[$key] = self::recursive_array_set( $value, $options[$key] );
                    } else {
                        $result[$key] = self::recursive_array_set( $value, array() );
                    }
                } else {
                    $result[$key] = $options[$key];
                }
            } else {
                if( is_array( $value ) ) {
                    $result[$key] = self::recursive_array_set( $value, array() );
                } else {
                    $result[$key] = '';
                }
            }
        }
        foreach( $options as $key => $value ) {
            if( ! array_key_exists( $key, $result ) ) {
                $result[$key] = $value;
            }
        }
        return $result;
    }
    public static function get_option() {
        $options = get_option( self::$values['settings_name'] );
        if ( @ $options && is_array ( $options ) ) {
            $options = array_merge( self::$defaults, $options );
        } else {
            $options = self::$defaults;
        }
        return $options;
    }
}

new gswcbr_product_brand;